@@ -6,7 +6,8 @@ import autoarray as aa
 
 def grid_to_pixel_pixels_via_nearest_neighbour(grid, pixel_centers):
     def compute_squared_separation(coordinate1, coordinate2):
-        """Computes the squared separation of two grid (no square root for efficiency)"""
+        """
+    Returns the squared separation of two grid (no square root for efficiency)"""
         return (coordinate1[0] - coordinate2[0]) ** 2 + (
             coordinate1[1] - coordinate2[1]
         ) ** 2
@@ -265,7 +266,7 @@ class TestRectangularMapper:
             [5],
         ]
 
-    def test__sub_to_pix__3x3_grid__change_arcsecond_dimensions_size__grid_adapts_accordingly(
+    def test__sub_to_pix__3x3_grid__change_scaledond_dimensions_size__grid_adapts_accordingly(
         self
     ):
         #   _ _ _
@@ -300,7 +301,7 @@ class TestRectangularMapper:
             [4],
         ]
 
-    def test__sub_to_pix__various_grids__change_arcsecond_dimensions__not_symmetric(
+    def test__sub_to_pix__various_grids__change_scaledond_dimensions__not_symmetric(
         self
     ):
         #   _ _ _
