@@ -30,7 +30,7 @@ def test__fit_quantities_are_output(fit_imaging_7x7, plot_path, plot_patch):
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "image.png" in plot_patch.paths
+    assert f"{plot_path}/image.png" in plot_patch.paths
 
     aplt.FitImaging.noise_map(
         fit=fit_imaging_7x7,
@@ -38,7 +38,7 @@ def test__fit_quantities_are_output(fit_imaging_7x7, plot_path, plot_patch):
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "noise_map.png" in plot_patch.paths
+    assert f"{plot_path}/noise_map.png" in plot_patch.paths
 
     aplt.FitImaging.signal_to_noise_map(
         fit=fit_imaging_7x7,
@@ -46,7 +46,7 @@ def test__fit_quantities_are_output(fit_imaging_7x7, plot_path, plot_patch):
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "signal_to_noise_map.png" in plot_patch.paths
+    assert f"{plot_path}/signal_to_noise_map.png" in plot_patch.paths
 
     aplt.FitImaging.model_image(
         fit=fit_imaging_7x7,
@@ -54,7 +54,7 @@ def test__fit_quantities_are_output(fit_imaging_7x7, plot_path, plot_patch):
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "model_image.png" in plot_patch.paths
+    assert f"{plot_path}/model_image.png" in plot_patch.paths
 
     aplt.FitImaging.residual_map(
         fit=fit_imaging_7x7,
@@ -62,7 +62,7 @@ def test__fit_quantities_are_output(fit_imaging_7x7, plot_path, plot_patch):
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "residual_map.png" in plot_patch.paths
+    assert f"{plot_path}/residual_map.png" in plot_patch.paths
 
     aplt.FitImaging.normalized_residual_map(
         fit=fit_imaging_7x7,
@@ -70,7 +70,7 @@ def test__fit_quantities_are_output(fit_imaging_7x7, plot_path, plot_patch):
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "normalized_residual_map.png" in plot_patch.paths
+    assert f"{plot_path}/normalized_residual_map.png" in plot_patch.paths
 
     aplt.FitImaging.chi_squared_map(
         fit=fit_imaging_7x7,
@@ -78,7 +78,7 @@ def test__fit_quantities_are_output(fit_imaging_7x7, plot_path, plot_patch):
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "chi_squared_map.png" in plot_patch.paths
+    assert f"{plot_path}/chi_squared_map.png" in plot_patch.paths
 
 
 def test__fit_sub_plot(fit_imaging_7x7, plot_path, plot_patch):
@@ -89,7 +89,7 @@ def test__fit_sub_plot(fit_imaging_7x7, plot_path, plot_patch):
         sub_plotter=aplt.SubPlotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "subplot_fit_imaging.png" in plot_patch.paths
+    assert f"{plot_path}/subplot_fit_imaging.png" in plot_patch.paths
 
 
 def test__fit_individuals__source_and_lens__depedent_on_input(
@@ -107,19 +107,19 @@ def test__fit_individuals__source_and_lens__depedent_on_input(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "image.png" in plot_patch.paths
+    assert f"{plot_path}/image.png" in plot_patch.paths
 
-    assert plot_path + "noise_map.png" not in plot_patch.paths
+    assert f"{plot_path}/noise_map.png" not in plot_patch.paths
 
-    assert plot_path + "signal_to_noise_map.png" not in plot_patch.paths
+    assert f"{plot_path}/signal_to_noise_map.png" not in plot_patch.paths
 
-    assert plot_path + "model_image.png" in plot_patch.paths
+    assert f"{plot_path}/model_image.png" in plot_patch.paths
 
-    assert plot_path + "residual_map.png" not in plot_patch.paths
+    assert f"{plot_path}/residual_map.png" not in plot_patch.paths
 
-    assert plot_path + "normalized_residual_map.png" not in plot_patch.paths
+    assert f"{plot_path}/normalized_residual_map.png" not in plot_patch.paths
 
-    assert plot_path + "chi_squared_map.png" in plot_patch.paths
+    assert f"{plot_path}/chi_squared_map.png" in plot_patch.paths
 
     aplt.FitImaging.individuals(
         fit=fit_imaging_7x7,
@@ -131,19 +131,19 @@ def test__fit_individuals__source_and_lens__depedent_on_input(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "image.png" in plot_patch.paths
+    assert f"{plot_path}/image.png" in plot_patch.paths
 
-    assert plot_path + "noise_map.png" not in plot_patch.paths
+    assert f"{plot_path}/noise_map.png" not in plot_patch.paths
 
-    assert plot_path + "signal_to_noise_map.png" not in plot_patch.paths
+    assert f"{plot_path}/signal_to_noise_map.png" not in plot_patch.paths
 
-    assert plot_path + "model_image.png" in plot_patch.paths
+    assert f"{plot_path}/model_image.png" in plot_patch.paths
 
-    assert plot_path + "residual_map.png" not in plot_patch.paths
+    assert f"{plot_path}/residual_map.png" not in plot_patch.paths
 
-    assert plot_path + "normalized_residual_map.png" not in plot_patch.paths
+    assert f"{plot_path}/normalized_residual_map.png" not in plot_patch.paths
 
-    assert plot_path + "chi_squared_map.png" in plot_patch.paths
+    assert f"{plot_path}/chi_squared_map.png" in plot_patch.paths
 
 
 def test__output_as_fits__correct_output_format(
@@ -158,7 +158,7 @@ def test__output_as_fits__correct_output_format(
     )
 
     image_from_plot = aa.util.array.numpy_array_2d_from_fits(
-        file_path=plot_path + "image.fits", hdu=0
+        file_path=f"{plot_path}/image.fits", hdu=0
     )
 
     assert image_from_plot.shape == (5, 5)
