@@ -36,7 +36,7 @@ def test__individual_attributes_are_output_for_rectangular_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "reconstructed_image.png" in plot_patch.paths
+    assert f"{plot_path}/reconstructed_image.png" in plot_patch.paths
 
     aplt.Inversion.reconstruction(
         inversion=rectangular_inversion_7x7_3x3,
@@ -47,7 +47,7 @@ def test__individual_attributes_are_output_for_rectangular_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "reconstruction.png" in plot_patch.paths
+    assert f"{plot_path}/reconstruction.png" in plot_patch.paths
 
     aplt.Inversion.errors(
         inversion=rectangular_inversion_7x7_3x3,
@@ -58,7 +58,7 @@ def test__individual_attributes_are_output_for_rectangular_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "errors.png" in plot_patch.paths
+    assert f"{plot_path}/errors.png" in plot_patch.paths
 
     aplt.Inversion.residual_map(
         inversion=rectangular_inversion_7x7_3x3,
@@ -69,7 +69,7 @@ def test__individual_attributes_are_output_for_rectangular_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "residual_map.png" in plot_patch.paths
+    assert f"{plot_path}/residual_map.png" in plot_patch.paths
 
     aplt.Inversion.normalized_residual_map(
         inversion=rectangular_inversion_7x7_3x3,
@@ -80,7 +80,7 @@ def test__individual_attributes_are_output_for_rectangular_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "normalized_residual_map.png" in plot_patch.paths
+    assert f"{plot_path}/normalized_residual_map.png" in plot_patch.paths
 
     aplt.Inversion.chi_squared_map(
         inversion=rectangular_inversion_7x7_3x3,
@@ -91,7 +91,7 @@ def test__individual_attributes_are_output_for_rectangular_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "chi_squared_map.png" in plot_patch.paths
+    assert f"{plot_path}/chi_squared_map.png" in plot_patch.paths
 
     aplt.Inversion.regularization_weights(
         inversion=rectangular_inversion_7x7_3x3,
@@ -102,7 +102,7 @@ def test__individual_attributes_are_output_for_rectangular_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "regularization_weights.png" in plot_patch.paths
+    assert f"{plot_path}/regularization_weights.png" in plot_patch.paths
 
     aplt.Inversion.interpolated_reconstruction(
         inversion=rectangular_inversion_7x7_3x3,
@@ -111,7 +111,7 @@ def test__individual_attributes_are_output_for_rectangular_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "interpolated_reconstruction.png" in plot_patch.paths
+    assert f"{plot_path}/interpolated_reconstruction.png" in plot_patch.paths
 
     aplt.Inversion.interpolated_errors(
         inversion=rectangular_inversion_7x7_3x3,
@@ -120,7 +120,7 @@ def test__individual_attributes_are_output_for_rectangular_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "interpolated_errors.png" in plot_patch.paths
+    assert f"{plot_path}/interpolated_errors.png" in plot_patch.paths
 
 
 def test__individual_attributes_are_output_for_voronoi_inversion(
@@ -136,7 +136,7 @@ def test__individual_attributes_are_output_for_voronoi_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "reconstructed_image.png" in plot_patch.paths
+    assert f"{plot_path}/reconstructed_image.png" in plot_patch.paths
 
     aplt.Inversion.reconstruction(
         inversion=voronoi_inversion_9_3x3,
@@ -147,7 +147,7 @@ def test__individual_attributes_are_output_for_voronoi_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "reconstruction.png" in plot_patch.paths
+    assert f"{plot_path}/reconstruction.png" in plot_patch.paths
 
     aplt.Inversion.errors(
         inversion=voronoi_inversion_9_3x3,
@@ -158,7 +158,7 @@ def test__individual_attributes_are_output_for_voronoi_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "errors.png" in plot_patch.paths
+    assert f"{plot_path}/errors.png" in plot_patch.paths
 
     aplt.Inversion.residual_map(
         inversion=voronoi_inversion_9_3x3,
@@ -169,7 +169,7 @@ def test__individual_attributes_are_output_for_voronoi_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "residual_map.png" in plot_patch.paths
+    assert f"{plot_path}/residual_map.png" in plot_patch.paths
 
     aplt.Inversion.normalized_residual_map(
         inversion=voronoi_inversion_9_3x3,
@@ -180,7 +180,7 @@ def test__individual_attributes_are_output_for_voronoi_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "normalized_residual_map.png" in plot_patch.paths
+    assert f"{plot_path}/normalized_residual_map.png" in plot_patch.paths
 
     aplt.Inversion.chi_squared_map(
         inversion=voronoi_inversion_9_3x3,
@@ -191,7 +191,7 @@ def test__individual_attributes_are_output_for_voronoi_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "chi_squared_map.png" in plot_patch.paths
+    assert f"{plot_path}/chi_squared_map.png" in plot_patch.paths
 
     aplt.Inversion.regularization_weights(
         inversion=voronoi_inversion_9_3x3,
@@ -202,7 +202,7 @@ def test__individual_attributes_are_output_for_voronoi_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "regularization_weights.png" in plot_patch.paths
+    assert f"{plot_path}/regularization_weights.png" in plot_patch.paths
 
     aplt.Inversion.interpolated_reconstruction(
         inversion=voronoi_inversion_9_3x3,
@@ -211,7 +211,7 @@ def test__individual_attributes_are_output_for_voronoi_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "interpolated_reconstruction.png" in plot_patch.paths
+    assert f"{plot_path}/interpolated_reconstruction.png" in plot_patch.paths
 
     aplt.Inversion.interpolated_errors(
         inversion=voronoi_inversion_9_3x3,
@@ -220,7 +220,7 @@ def test__individual_attributes_are_output_for_voronoi_inversion(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "interpolated_errors.png" in plot_patch.paths
+    assert f"{plot_path}/interpolated_errors.png" in plot_patch.paths
 
 
 def test__inversion_subplot_is_output_for_all_inversions(
@@ -236,7 +236,7 @@ def test__inversion_subplot_is_output_for_all_inversions(
         source_pixel_indexes=[[1, 2], [0]],
         sub_plotter=aplt.SubPlotter(output=aplt.Output(path=plot_path, format="png")),
     )
-    assert plot_path + "subplot_inversion.png" in plot_patch.paths
+    assert f"{plot_path}/subplot_inversion.png" in plot_patch.paths
 
     aplt.Inversion.subplot_inversion(
         inversion=voronoi_inversion_9_3x3,
@@ -244,7 +244,7 @@ def test__inversion_subplot_is_output_for_all_inversions(
         source_pixel_indexes=[[1, 2], [0]],
         sub_plotter=aplt.SubPlotter(output=aplt.Output(path=plot_path, format="png")),
     )
-    assert plot_path + "subplot_inversion.png" in plot_patch.paths
+    assert f"{plot_path}/subplot_inversion.png" in plot_patch.paths
 
 
 def test__inversion_individuals__output_dependent_on_input(
@@ -260,11 +260,11 @@ def test__inversion_individuals__output_dependent_on_input(
         plotter=aplt.Plotter(output=aplt.Output(path=plot_path, format="png")),
     )
 
-    assert plot_path + "reconstructed_image.png" in plot_patch.paths
-    assert plot_path + "reconstruction.png" not in plot_patch.paths
-    assert plot_path + "errors.png" in plot_patch.paths
-    assert plot_path + "residual_map.png" not in plot_patch.paths
-    assert plot_path + "normalized_residual_map.png" not in plot_patch.paths
-    assert plot_path + "chi_squared_map.png" in plot_patch.paths
-    assert plot_path + "interpolated_reconstruction.png" in plot_patch.paths
-    assert plot_path + "interpolated_errors.png" not in plot_patch.paths
+    assert f"{plot_path}/reconstructed_image.png" in plot_patch.paths
+    assert f"{plot_path}/reconstruction.png" not in plot_patch.paths
+    assert f"{plot_path}/errors.png" in plot_patch.paths
+    assert f"{plot_path}/residual_map.png" not in plot_patch.paths
+    assert f"{plot_path}/normalized_residual_map.png" not in plot_patch.paths
+    assert f"{plot_path}/chi_squared_map.png" in plot_patch.paths
+    assert f"{plot_path}/interpolated_reconstruction.png" in plot_patch.paths
+    assert f"{plot_path}/interpolated_errors.png" not in plot_patch.paths
