@@ -636,7 +636,7 @@ class TestAbstractPlotterPlots:
             include_border=True,
         )
 
-        assert plot_path + "array1.png" in plot_patch.paths
+        assert f"{plot_path}/array1.png" in plot_patch.paths
 
         plotter = aplt.Plotter(
             output=aplt.Output(path=plot_path, filename="array2", format="png")
@@ -655,7 +655,7 @@ class TestAbstractPlotterPlots:
             include_border=True,
         )
 
-        assert plot_path + "array2.png" in plot_patch.paths
+        assert f"{plot_path}/array2.png" in plot_patch.paths
 
         aplt.Array(
             array=array,
@@ -670,11 +670,11 @@ class TestAbstractPlotterPlots:
             ),
         )
 
-        assert plot_path + "array3.png" in plot_patch.paths
+        assert f"{plot_path}/array3.png" in plot_patch.paths
 
     def test__plot_array__fits_files_output_correctly(self, plot_path):
 
-        plot_path = plot_path + "/fits/"
+        plot_path = f"{plot_path}//fits/"
 
         if os.path.exists(plot_path):
             shutil.rmtree(plot_path)
@@ -688,7 +688,7 @@ class TestAbstractPlotterPlots:
         plotter.plot_array(array=arr)
 
         arr = aa.util.array.numpy_array_2d_from_fits(
-            file_path=plot_path + "/array.fits", hdu=0
+            file_path=f"{plot_path}//array.fits", hdu=0
         )
 
         assert (arr == np.ones(shape=(31, 31))).all()
@@ -702,7 +702,7 @@ class TestAbstractPlotterPlots:
         plotter.plot_array(array=masked_array)
 
         arr = aa.util.array.numpy_array_2d_from_fits(
-            file_path=plot_path + "/array.fits", hdu=0
+            file_path=f"{plot_path}//array.fits", hdu=0
         )
 
         assert arr.shape == (13, 13)
@@ -717,7 +717,7 @@ class TestAbstractPlotterPlots:
 
         plotter.plot_frame(frame=frame, include_origin=True)
 
-        assert plot_path + "frame1.png" in plot_patch.paths
+        assert f"{plot_path}/frame1.png" in plot_patch.paths
 
         plotter = aplt.Plotter(
             output=aplt.Output(path=plot_path, filename="frame2", format="png")
@@ -725,7 +725,7 @@ class TestAbstractPlotterPlots:
 
         plotter.plot_frame(frame=frame, include_origin=True)
 
-        assert plot_path + "frame2.png" in plot_patch.paths
+        assert f"{plot_path}/frame2.png" in plot_patch.paths
 
         aplt.Frame(
             frame=frame,
@@ -734,11 +734,11 @@ class TestAbstractPlotterPlots:
             ),
         )
 
-        assert plot_path + "frame3.png" in plot_patch.paths
+        assert f"{plot_path}/frame3.png" in plot_patch.paths
 
     def test__plot_frame__fits_files_output_correctly(self, plot_path):
 
-        plot_path = plot_path + "/fits/"
+        plot_path = f"{plot_path}//fits/"
 
         if os.path.exists(plot_path):
             shutil.rmtree(plot_path)
@@ -752,7 +752,7 @@ class TestAbstractPlotterPlots:
         plotter.plot_frame(frame=frame)
 
         frame = aa.util.array.numpy_array_2d_from_fits(
-            file_path=plot_path + "/frame.fits", hdu=0
+            file_path=f"{plot_path}//frame.fits", hdu=0
         )
 
         assert (frame == np.ones(shape=(31, 31))).all()
@@ -764,7 +764,7 @@ class TestAbstractPlotterPlots:
         plotter.plot_frame(frame=masked_frame)
 
         frame = aa.util.array.numpy_array_2d_from_fits(
-            file_path=plot_path + "/frame.fits", hdu=0
+            file_path=f"{plot_path}//frame.fits", hdu=0
         )
 
         assert frame.shape == (31, 31)
@@ -788,7 +788,7 @@ class TestAbstractPlotterPlots:
             symmetric_around_centre=False,
         )
 
-        assert plot_path + "grid1.png" in plot_patch.paths
+        assert f"{plot_path}/grid1.png" in plot_patch.paths
 
         plotter = aplt.Plotter(
             output=aplt.Output(path=plot_path, filename="grid2", format="png")
@@ -805,7 +805,7 @@ class TestAbstractPlotterPlots:
             symmetric_around_centre=True,
         )
 
-        assert plot_path + "grid2.png" in plot_patch.paths
+        assert f"{plot_path}/grid2.png" in plot_patch.paths
 
         aplt.Grid(
             grid=grid,
@@ -821,7 +821,7 @@ class TestAbstractPlotterPlots:
             ),
         )
 
-        assert plot_path + "grid3.png" in plot_patch.paths
+        assert f"{plot_path}/grid3.png" in plot_patch.paths
 
     def test__plot_line__works_with_all_extras_included(self, plot_path, plot_patch):
 
@@ -838,7 +838,7 @@ class TestAbstractPlotterPlots:
             vertical_line_labels=["line1", "line2"],
         )
 
-        assert plot_path + "line1.png" in plot_patch.paths
+        assert f"{plot_path}/line1.png" in plot_patch.paths
 
         plotter = aplt.Plotter(
             output=aplt.Output(path=plot_path, filename="line2", format="png")
@@ -853,7 +853,7 @@ class TestAbstractPlotterPlots:
             vertical_line_labels=["line1", "line2"],
         )
 
-        assert plot_path + "line2.png" in plot_patch.paths
+        assert f"{plot_path}/line2.png" in plot_patch.paths
 
         aplt.Line(
             y=np.array([1.0, 2.0, 3.0]),
@@ -867,7 +867,7 @@ class TestAbstractPlotterPlots:
             ),
         )
 
-        assert plot_path + "line3.png" in plot_patch.paths
+        assert f"{plot_path}/line3.png" in plot_patch.paths
 
     def test__plot_rectangular_mapper__works_with_all_extras_included(
         self, rectangular_mapper_7x7_3x3, plot_path, plot_patch
@@ -886,7 +886,7 @@ class TestAbstractPlotterPlots:
             source_pixel_indexes=[[0, 1], [2]],
         )
 
-        assert plot_path + "mapper1.png" in plot_patch.paths
+        assert f"{plot_path}/mapper1.png" in plot_patch.paths
 
         plotter = aplt.Plotter(
             output=aplt.Output(path=plot_path, filename="mapper2", format="png")
@@ -901,7 +901,7 @@ class TestAbstractPlotterPlots:
             source_pixel_indexes=[[0, 1], [2]],
         )
 
-        assert plot_path + "mapper2.png" in plot_patch.paths
+        assert f"{plot_path}/mapper2.png" in plot_patch.paths
 
         aplt.MapperObj(
             mapper=rectangular_mapper_7x7_3x3,
@@ -917,7 +917,7 @@ class TestAbstractPlotterPlots:
             ),
         )
 
-        assert plot_path + "mapper3.png" in plot_patch.paths
+        assert f"{plot_path}/mapper3.png" in plot_patch.paths
 
     def test__plot_voronoi_mapper__works_with_all_extras_included(
         self, voronoi_mapper_9_3x3, plot_path, plot_patch
@@ -936,7 +936,7 @@ class TestAbstractPlotterPlots:
             source_pixel_indexes=[[0, 1], [2]],
         )
 
-        assert plot_path + "mapper1.png" in plot_patch.paths
+        assert f"{plot_path}/mapper1.png" in plot_patch.paths
 
         plotter = aplt.Plotter(
             output=aplt.Output(path=plot_path, filename="mapper2", format="png")
@@ -951,7 +951,7 @@ class TestAbstractPlotterPlots:
             source_pixel_indexes=[[0, 1], [2]],
         )
 
-        assert plot_path + "mapper2.png" in plot_patch.paths
+        assert f"{plot_path}/mapper2.png" in plot_patch.paths
 
         aplt.MapperObj(
             mapper=voronoi_mapper_9_3x3,
@@ -967,7 +967,7 @@ class TestAbstractPlotterPlots:
             ),
         )
 
-        assert plot_path + "mapper3.png" in plot_patch.paths
+        assert f"{plot_path}/mapper3.png" in plot_patch.paths
 
 
 class TestAbstractPlotterNew:
