@@ -12,6 +12,7 @@ class TestFrameAPI:
 
         frame = aa.Frame.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
+            pixel_scales=1.0,
             roe_corner=(1, 0),
             scans=aa.Scans(
                 parallel_overscan=(0, 1, 0, 1),
@@ -32,6 +33,7 @@ class TestFrameAPI:
 
         frame = aa.Frame.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
+            pixel_scales=1.0,
             roe_corner=(0, 0),
             scans=aa.Scans(
                 parallel_overscan=(0, 1, 0, 1),
@@ -50,6 +52,7 @@ class TestFrameAPI:
 
         frame = aa.Frame.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
+            pixel_scales=1.0,
             roe_corner=(1, 1),
             scans=aa.Scans(
                 parallel_overscan=(0, 1, 0, 1),
@@ -68,6 +71,7 @@ class TestFrameAPI:
 
         frame = aa.Frame.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
+            pixel_scales=1.0,
             roe_corner=(0, 1),
             scans=aa.Scans(
                 parallel_overscan=(0, 1, 0, 1),
@@ -89,6 +93,7 @@ class TestFrameAPI:
         frame = aa.Frame.full(
             fill_value=8.0,
             shape_2d=(2, 2),
+            pixel_scales=1.0,
             roe_corner=(1, 0),
             scans=aa.Scans(
                 parallel_overscan=(0, 1, 0, 1),
@@ -106,6 +111,7 @@ class TestFrameAPI:
 
         frame = aa.Frame.ones(
             shape_2d=(2, 2),
+            pixel_scales=1.0,
             roe_corner=(1, 0),
             scans=aa.Scans(
                 parallel_overscan=(0, 1, 0, 1),
@@ -123,6 +129,7 @@ class TestFrameAPI:
 
         frame = aa.Frame.zeros(
             shape_2d=(2, 2),
+            pixel_scales=1.0,
             roe_corner=(1, 0),
             scans=aa.Scans(
                 parallel_overscan=(0, 1, 0, 1),
@@ -142,6 +149,7 @@ class TestFrameAPI:
 
         frame = aa.Frame.manual(
             array=[[1.0, 2.0, 3.0], [4.0, 5.0, 6.0], [7.0, 8.0, 9.0]],
+            pixel_scales=1.0,
             roe_corner=(1, 0),
             scans=aa.Scans(
                 parallel_overscan=None,
@@ -165,7 +173,7 @@ class TestFrameAPI:
         self
     ):
 
-        mask = aa.Mask2D.manual(mask=[[False, True], [False, False]])
+        mask = aa.Mask2D.manual(mask=[[False, True], [False, False]], pixel_scales=1.0)
 
         frame = aa.Frame.manual_mask(
             array=[[1.0, 2.0], [3.0, 4.0]],
@@ -241,10 +249,11 @@ class TestFrameAPI:
 
     def test__from_frame__no_rotation_as_frame_is_correct_orientation(self):
 
-        mask = aa.Mask2D.manual(mask=[[False, True], [False, False]])
+        mask = aa.Mask2D.manual(mask=[[False, True], [False, False]], pixel_scales=1.0)
 
         frame = aa.Frame.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
+            pixel_scales=1.0,
             roe_corner=(1, 0),
             scans=aa.Scans(
                 parallel_overscan=(0, 1, 0, 1),
@@ -262,10 +271,11 @@ class TestFrameAPI:
         assert frame.scans.serial_overscan == (0, 2, 0, 2)
         assert (frame.mask == np.array([[False, True], [False, False]])).all()
 
-        mask = aa.Mask2D.manual(mask=[[False, True], [False, False]])
+        mask = aa.Mask2D.manual(mask=[[False, True], [False, False]], pixel_scales=1.0)
 
         frame = aa.Frame.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
+            pixel_scales=1.0,
             roe_corner=(0, 0),
             scans=aa.Scans(
                 parallel_overscan=(0, 1, 0, 1),
